/** 
 *   Site testing for SKA candidate.
 *
 *   (c) Copyright 2004 Federico Bareilles <fede@iar.unlp.edu.ar>,
 *   Instituto Argentino de Radio Astronomia (IAR).
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *     
 *   The author does NOT admit liability nor provide warranty for any
 *   of this software. This material is provided "AS-IS" in the hope
 *   that it may be useful for others.
 *
 **/


#define _GNU_SOURCE

#include <stdio.h>
#include <string.h>
#include <getopt.h>
#include "version.h"
#include "observ_table.h"
#include "toska.h"
#include "my_stdio.h"



char *help_text[] ={
//	"  -d\t\t\t- set data directoy (def.: "DATA_DIR")",
	"  -f\t\t\t- set modes definition file (def.: "MODES_FILE")",
	"  -s\t\t\t- set sequence file (def.: "SEQUENCE_FILE")",
	"  -S\t\t\t- output sequence list.",
	"  -V\t\t\t- show program version.",
	"  --help\t\t- this help !!!.",
	""
};


void version(char *program_name)
{
	fprintf(stderr,"%s version %s\n", program_name, VERSION);
}


void usage(char *program_name)
{
	fprintf(stderr,
		"Usage: \t%s [-hfs][--help]\n",
		program_name);
}


void help()
{
	int i=0;

	while((char) *help_text[i] != 0)
		fprintf(stderr,"%s\n",help_text[i++]);
	fprintf(stderr,"\n");
}


int main(int argc, char **argv)
{
	struct modes *obs, *obsp;
	struct sequence *seq, *seqp;
	char *data_dir=DATA_DIR;
	char *modes_file = MODES_FILE;
	char *sequence_file = SEQUENCE_FILE;
	char *program_name;
	int out_sequence_flag = 0;
	char *cp;
	int op;
	static struct option  const  longopts[] =
	{
		{"help", 0, 0, 101},
		{0,  0,  0,  0}
	};

	/* who is my name? */
	if ((cp = strrchr(argv[0], '/')) != NULL) program_name  = cp + 1;
	else program_name  = argv[0];
  
	verbose_flag = 0;
	opterr =  0;
	while  ((op = getopt_long(argc, argv, "Vvf:s:S",longopts, 0)) != EOF)
		switch( op ){
		case 'v':
			verbose_flag = (verbose_flag << 1) | 1;
			break;
		case 101:
			usage(program_name);
			help();
			exit(-1);
			break;
		case 'd':
			data_dir = optarg;
			break;
		case 'f':
			modes_file = optarg;
			break;
		case 's':
			sequence_file = optarg;
			break;
		case 'S':
			out_sequence_flag = 1;
			break;
		case 'V':
			version(program_name);
			exit(-1);
			break;
		default:
			usage(program_name);
			exit(-1);
		}
	


	obs = obsp = get_modes_table(modes_file);
	if( obs == NULL){
		PVERB(PERR, "Error opening modes file: %s.\n",
		       modes_file );
		exit(1);
	}
	seq = seqp = get_sequence_table(sequence_file);
	if( seq == NULL){
		PVERB(PERR, "Error opening sequence file: %s.\n",
		       sequence_file );
		exit(1);
	}

	if (out_sequence_flag) {
		printf("#M Az Pol Time\n");
		while (seqp != NULL ) {
			printf("%1d %03d %c  %6d\n", 
			       seqp->mode, seqp->azimuth, seqp->polarization,
			       (int)time_estimation_mode(seqp->mode, obs));
			seqp = seqp->next;
		}
	}else {
		printf("#M StartFre StopFreq RBW  Swee R S\n");
		while( obsp != NULL){
			printf("%d %8.5f %8.5f %4d %4d %2d %c\n", 
			       obsp->mode, obsp->start_freq, obsp->stop_freq,
			       obsp->RBW, obsp->sweep, obsp->repetitions, 
			       obsp->switchs);
			obsp = obsp->next;
		}
	}
	free_modes_table(obs);
	free_sequence_table(seq);

	return 0;
}

